pub struct CreatableProjectGalleryItem {
pub item: Option<String>,
pub featured: Option<bool>,
pub title: Option<Option<String>>,
pub description: Option<Option<String>>,
pub ordering: Option<i32>,
}Fields
item: Option<String>The name of the multipart item where the gallery media is located
featured: Option<bool>Whether the image is featured in the gallery
title: Option<Option<String>>The title of the gallery image
description: Option<Option<String>>The description of the gallery image
ordering: Option<i32>The order of the gallery image. Gallery images are sorted by this field and then alphabetically by title.
Implementations
Sourceimpl CreatableProjectGalleryItem
impl CreatableProjectGalleryItem
pub fn new() -> CreatableProjectGalleryItem