pub struct ForgeUpdates {
pub homepage: Option<String>,
pub promos: Option<ForgeUpdateCheckerPromos>,
}Expand description
ForgeUpdates : Mod version information that can be consumed by Forge’s update checker
Fields
homepage: Option<String>A link to the mod page
promos: Option<ForgeUpdateCheckerPromos>Implementations
Sourceimpl ForgeUpdates
impl ForgeUpdates
Sourcepub fn new() -> ForgeUpdates
pub fn new() -> ForgeUpdates
Mod version information that can be consumed by Forge’s update checker