pub struct GalleryImage {
pub url: String,
pub featured: bool,
pub title: Option<Option<String>>,
pub description: Option<Option<String>>,
pub created: String,
pub ordering: Option<i32>,
}Fields
url: StringThe URL of the gallery image
featured: boolWhether the image is featured in the gallery
title: Option<Option<String>>The title of the gallery image
description: Option<Option<String>>The description of the gallery image
created: StringThe date and time the gallery image was created
ordering: Option<i32>The order of the gallery image. Gallery images are sorted by this field and then alphabetically by title.
Implementations
Sourceimpl GalleryImage
impl GalleryImage