pub struct ModifyTeamMemberBody {
pub role: Option<String>,
pub permissions: Option<i32>,
pub payouts_split: Option<i32>,
pub ordering: Option<i32>,
}Fields
role: Option<String>permissions: Option<i32>The user’s permissions in bitfield format In order from first to tenth bit, the bits are: - UPLOAD_VERSION - DELETE_VERSION - EDIT_DETAILS - EDIT_BODY - MANAGE_INVITES - REMOVE_MEMBER - EDIT_MEMBER - DELETE_PROJECT - VIEW_ANALYTICS - VIEW_PAYOUTS
payouts_split: Option<i32>The split of payouts going to this user. The proportion of payouts they get is their split divided by the sum of the splits of all members.
ordering: Option<i32>The order of the team member.
Implementations
Sourceimpl ModifyTeamMemberBody
impl ModifyTeamMemberBody
pub fn new() -> ModifyTeamMemberBody